#version 330 core

in vec2 uv;
in vec2 pos;
in vec2 centerPos;

out vec4 outColor;

uniform sampler2D tex2d;
uniform float gearCounter;
uniform float stabilityLevel = 0.5;
uniform float shadeYPos;
uniform float hotbarYPos;
uniform float gearHeight;

#include noise3d.ash

float getAngle(vec2 v) {
  v = normalize(v);
  float dotProduct = dot(v, vec2(1.0, 0.0));
  float crossProduct = v.x * 0.0 - v.y * (-1.0);
  float angle = atan(crossProduct, dotProduct);
  angle = degrees(angle);

  return angle;
}

void main() {
  vec4 tealCol = vec4(56 / 255.0, 232 / 255.0, 182 / 255.0, 1.0);
  vec4 rustCol = vec4(0.45, 0.30, 0.20, 0.25);
  vec4 redCol = vec4(0.6, 0.1, 0.1, 1.0);

  outColor = texture(tex2d, uv);
  if (outColor.a <= 0.01)
    discard;

  float noise =
      abs(gnoise(vec3(pos.x / 20.0, pos.y / 20.0, gearCounter * 0.75)));

  vec2 normal = normalize(centerPos - pos);
  float angle = getAngle(normal) + noise * 20.0;

  float percentage = clamp(angle / 180.0, 0.0, 1.0);

  float mixPower = clamp(1 - (percentage - stabilityLevel) * 15.0, 0, 1);

  float b = 1.2 * (max(0, 0.4 - (outColor.r + outColor.g + outColor.b) / 3.0) +
                   noise / 5.0);

  tealCol.a *= outColor.a;
  redCol.a *= outColor.a;
  rustCol.a *= outColor.a;

  float fastNoise = abs(gnoise(vec3(pos.x / 2, pos.y / 2, 0.0)));
  redCol = mix(rustCol, redCol, fastNoise);

  float rustNoise =
      abs(gnoise(vec3(pos.x / 20, pos.y / 20,
                      gearCounter * 0.25 + ceil(gearCounter * 0.5)))) *
      10.0;
  rustCol = mix(rustCol, redCol, rustNoise);

  outColor = mix(rustCol, tealCol, mixPower);

  outColor.rgb -= b;
}